@@ -180,6 +180,10 @@ class Ep2Group:
         """Creates the path to the attendance CSV file for an exercise for a group"""
         return os.path.join(self.ep2.tutor_repo(), self.name, "students.csv")
 
+    def statistics_file(self, ue: int):
+        """Returns the path to the statistics file for a given exercise"""
+        return os.path.join(self.ep2.tutor_repo(), self.name, "statistics_{}.txt".format(ue))
+
     def team_csv(self):
         """Creates the path to the attendance CSV file for an exercise for a group"""
         return os.path.join(self.ep2.tutor_repo(), self.name, "teams.csv")
