@@ -17,6 +17,7 @@ KEY_UE_ATTENDED = 'attended'
 KEY_UE_REMARKS = 'remarks'
 KEY_UE_FEEDBACK = 'feedback'
 KEY_UE_GRADING = 'grading'
+KEY_UE_BUILD_STATUS = 'build_status'
 KEY_UE_PRE_EVAL_EX = 'pre_eval_ex_%02d'
 
 
@@ -69,7 +70,7 @@ def attendance_csv_fieldnames(ep2: Ep2, ue: int) -> [str]:
 
 def pre_eval_csv_fieldnames(ep2: Ep2, ue: int) -> [str]:
     sub_exercises = [KEY_UE_PRE_EVAL_EX % d for d in range(1, ep2.tests_for_exercise(ue) + 1)]
-    return [KEY_STUDENT_ID, KEY_UE_ATTENDED, KEY_UE_REMARKS, KEY_UE_FEEDBACK, KEY_UE_GRADING] + sub_exercises
+    return [KEY_STUDENT_ID, KEY_UE_ATTENDED, KEY_UE_REMARKS, KEY_UE_FEEDBACK, KEY_UE_BUILD_STATUS, KEY_UE_GRADING] + sub_exercises
 
 
 def pre_eval_csv_fieldnames_ta():
@@ -153,7 +154,7 @@ def checkout(ctx, group, ue: int):
 
                     if curr_ue_type == ExerciseType.Normal:
                         sub_exercises = {KEY_UE_PRE_EVAL_EX % d: '0/0' for d in range(1, ep2.tests_for_exercise(ue) + 1)}
-                        writer.writerow({KEY_STUDENT_ID: student_id, KEY_UE_GRADING: '_', KEY_UE_REMARKS: '', KEY_UE_FEEDBACK: '', KEY_UE_ATTENDED: 0, **sub_exercises})
+                        writer.writerow({KEY_STUDENT_ID: student_id, KEY_UE_GRADING: '_', KEY_UE_REMARKS: '', KEY_UE_FEEDBACK: '', KEY_UE_ATTENDED: 0, KEY_UE_BUILD_STATUS: 'unknown', **sub_exercises})
                     elif curr_ue_type == ExerciseType.Team:
                         writer.writerow(
                             {KEY_STUDENT_ID: student_id, KEY_UE_TA_POINTS: '_', KEY_UE_REMARKS: '',
